/*--------------------------------------------------------------------------
 * Copyright (C) 1992,1993,1994,1995 Dallas Semiconductor Corporation. 
 * All rights Reserved. Printed in U.S.A.
 * This software is protected by copyright laws of
 * the United States and of foreign countries.
 * This material may also be protected by patent laws of the United States 
 * and of foreign countries.
 * This software is furnished under a license agreement and/or a
 * nondisclosure agreement and may only be used or copied in accordance
 * with the terms of those agreements.
 * The mere transfer of this software does not imply any licenses
 * of trade secrets, proprietary technology, copyrights, patents,
 * trademarks, maskwork rights, or any other form of intellectual
 * property whatsoever. Dallas Semiconductor retains all ownership rights.
 *--------------------------------------------------------------------------
 *
 *   TMEXUTIL.H - Include header file for the TMEX utilities.  This file
 *                contains constants, typedef's, and global variables.
 *
 *  Compiler: Borland C++ 3.1 / Microsoft C 8.0
 *  Version: 2.10
 *
 *  Revision History:
 *
 *     1.00 => 1.10   1) Force no direct video writes.
 *
 *                    2) Add a global flag that is set if the 1-Wire
 *                       is setup.
 *
 *                    3) Remove CRC16 and DOWCRC because they are not used.
 *
 *                    4) Added new error codes. 
 *                                             
 *
 *     1.00 => 2.00   1) Create FamSpec for a list of device sizes and
 *                       and memory type.
 *                    
 *                    2) Added new error codes.
 *
 *     2.00 => 2.10   1) Updated FamSpec for new devices.
 *
 */

/* includes */
#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include <string.h>
#include <dos.h>
#include <ctype.h>
#include <fcntl.h>
#include <io.h>
#include <time.h>

/* type defs */
typedef unsigned char uchar;
typedef unsigned int  uint;

/* typedef structure sent back by TMEX routines */
typedef struct      
{
        uchar name[4];
        uchar extension;
        uchar startpage;
        uchar numpages;
        uchar attrib;
        uchar bitmap[32];
} FileEntry;
/* structure to hold all device parameters by family code */
typedef struct
{
   uchar maxp;    /* max page number 0-255 */
   uchar memtype; /* 0 no mem , 1 nvram, 2 DS1982 type, 3 DS1985 and DS1986, 
                     4 DS2407, 5 eeprom DS1971 */
   char  *dsnum;  /* Dallas Semiconductor part number */
} Family;
typedef struct
{
   uchar NumEntries;      /* number of entries in path 0-10 */
   char  Ref;             /* reference character '\' or '.' */
   char  Entries[10][4];  /* sub-directory entry names */                                          
} DirectoryPath;
                                          
/* declaration defines */
#define FAR     _far
#define PASCAL  _pascal

/* Error codes from TMEX functions */
// TMEX Error codes
// TMEX Error codes
#define XNO_DEVICE             -1
#define XWRONG_TYPE            -2
#define XFILE_READ_ERR         -3
#define XBUFFER_TOO_SMALL      -4
#define XHANDLE_NOT_AVAIL      -5
#define XFILE_NOT_FOUND        -6
#define XREPEAT_FILE           -7
#define XHANDLE_NOT_USED       -8
#define XFILE_WRITE_ONLY       -9
#define XOUT_OF_SPACE          -10
#define XFILE_WRITE_ERR        -11
#define XFILE_READ_ONLY        -12
#define XFUNC_NOT_SUP          -13
#define XBAD_FILENAME          -14
#define XCANT_DEL_READ_ONLY    -15
#define XHANDLE_NOT_EXIST      -16
#define XONE_WIRE_PORT_ERROR   -17    
#define XINVALID_DIRECTORY     -18
#define XDIRECTORY_NOT_EMPTY   -19 
#define XUNABLE_TO_CREATE_DIR  -20
#define XNO_PROGRAM_JOB        -21  
#define XPROGRAM_WRITE_PROTECT -22        
#define XNON_PROGRAM_PARTS     -23
#define XADDFILE_TERMINATED    -24    
#define XTIMEOUT               -25     
#define XINVALID_ARGUMENT      -26    
#define XBAD_ACK               -27    
#define XINVALID_SESSION       -200 
#define XNO_BASDRV_FOUND       -201   

// Basic physical level error codes
#define BPORT_NOT_INITIALIZED  -1
#define BPORT_NOT_EXIST        -2
#define BNO_SUCH_FUNCTION      -3   

// Transport level error codes
#define TERROR_READ_WRITE      -4
#define TBUFFER_TOO_SMALL      -5
#define TDEVICE_TOO_SMALL      -6
#define TNO_DEVICE             -7
#define TBLOCK_TOO_BIG         -8
#define TWRONG_TYPE            -9    
#define TPAGE_REDIRECTED       -10   
#define TPROGRAM_NOT_POSSIBLE  -11
#define BCOM_FAILURE           -12
#define BCOM_EVENT             -13
// other
#define GENERAL_FAIL           -2  


#define BAD_ARGUMENT           50
#define NO_DRIVERS             51
#define KEY_ABORT              52
#define OUT_MEMORY             53
#define NORMAL_EXIT            0

#define TRUE                   1
#define FALSE                  0
#define DIR_READ               1
#define DIR_SET                0
#define DIR_REMOVE             1
#define DIR_MAKE               0


